@@ -74,7 +74,7 @@ config_network(){
     exit 1
   elif [ "$IP_no" -eq 1 ]; then
     [ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
-    echo $msg_only_one_IP_so_create_alias_IP
+    echo -n $msg_only_one_IP_so_create_alias_IP
     [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
     alias_done="no"
     i="$private_IP_alias_eth_def"
@@ -94,16 +94,19 @@ iface eth0:1 inet static
 	netmask 255.255.255.0
 NET_END
     fi
-
+    echo "$msg_done!"
   else
     # More than one IP address, so it's not necessary to use alias IP address.
     [ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
     echo $msg_more_than_1_IP_some_for_DRBL_clients
     [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
   fi
+} # end of config_network
 
-}
 
+#################
+##### MAIN ######
+#################
 check_if_root
 
 #
@@ -127,14 +130,34 @@ case "$switch" in
      echo $msg_this_might_take_several_minutes
      echo -n $msg_press_enter_to_continue
      read
-     # run drblpush again so that the network interface can be updated. Maybe there is new ethx.
-     # load $client_no_per_NIC
+
+     # load $client_no_per_NIC and $autologin_passwd_opt for later use
      . /opt/drbl/setup/files/ocs/live-hook/ocs-live.conf
+
+     # run drblpush again so that the network interface can be updated. Maybe there is new ethx.
      yes "" | drblpush -i -r 1 -z 1 -p $client_no_per_NIC
 
+     echo "$msg_delimiter_star_line"
      # modify dhcpd.conf, provide IP address to PXE/Etherboot/DRBL client only
-     perl -pi -e 's/^([[:space:]]*)#([[:space:]]*allow members of "DRBL-Client";)/$1 $2/g' /etc/dhcp3/dhcpd.conf
+     echo "Modifying dhcpd.conf, now only PXE/Etherboot/DRBL client can lease IP address..."
+     perl -pi -e 's/^([[:space:]]*)#[[:space:]]*(allow members of "DRBL-Client";)/$1 $2/g' /etc/dhcp3/dhcpd.conf
+     /etc/init.d/dhcp3-server restart
 
+     echo "$msg_delimiter_star_line"
+     echo "Enable auto login for drbl clients..."
+     # enable autologin
+     case "$autologin_passwd_opt" in
+       "random")
+         make_random_password $password_opt
+         passwd_autologin="$random_password"
+         ;;
+       *)
+         passwd_autologin="$passwd_autologin_def"
+         ;;
+     esac
+     drbl-login-switch -a -p "${passwd_autologin}"
+
+     echo "$msg_delimiter_star_line"
      # turn on tcpwrapper
      echo "Setting /etc/hosts.allow..."
      mv -f /etc/hosts.allow /etc/hosts.allow.orig
@@ -158,7 +181,11 @@ case "$switch" in
      set_locale_for_clients
 
      #
+     echo "$msg_delimiter_star_line"
      echo "$msg_done!"
+     echo "$msg_all_set_you_can_turn_on_clients"
+     echo -n $msg_press_enter_to_continue
+     read
      ;;
    "stop")
      # block all the clients.
@@ -170,5 +197,10 @@ case "$switch" in
      drbl-all-service stop
      echo "Removing DRBL-related services..."
      drbl-all-service del
+     #
+     echo "$msg_delimiter_star_line"
+     echo "$msg_done!"
+     echo -n $msg_press_enter_to_continue
+     read
      ;;
 esac
